#!/bin/sh
#
#set -x

NAME="sdr"
PROGRAM="$NAME.sh"
UPDATE="2006/06/22"

HEADLINE="\
###########################################################################\\n\
# $PROGRAM                                                                 \\n\
###########################################################################\\n\
# Supero Doctor Report Shell Script                                        \\n\
# This shell script is used to collect information for troubleshooting.    \\n\
# Copyright @ Super Micro Computer, Inc.                                   \\n\
# Update: $UPDATE                                                          \\n\
###########################################################################\\n\
"
CAT=`which cat`
DATE=`which date`
DMIDECODE=`which dmidecode`
ECHO=`which echo`
GREP=`which grep`
LS=`which ls`
LSPCI=`which lspci`
LSMOD=`which lsmod`
SDT=`which sdt` 
UNAME=`which uname`

OUTPUT_TXT=$NAME-`$DATE +%Y%m%d-%H%M`.txt

function showHeadline()
{
    $ECHO -e $HEADLINE
}

function showCurrentTime()
{
    $DATE
}
function showSystemInfo()
{
    $UNAME -a
}

function showBIOSDMI()
{
    $DMIDECODE
}

function showLinuxDistribution()
{
    if [ -f  /etc/issue ]; then
        $CAT /etc/issue
    else
        $ECHO "N/A, Not available."
    fi
}
function showSDInfo()
{
    $SDT 
    if [ -f /etc/SuperD.ini ]; then
        $CAT /etc/SuperD.ini
    else
        $ECHO "N/A, Not available."
    fi
}

function showPCIInfo()
{
    $LSPCI -n 
    $LSPCI -vv
}

function showLoadedModule()
{
    $LSMOD
}

function showI2CBus()
{
    if [ -e /proc/bus/i2c ]; then
        $CAT /proc/bus/i2c
    else
        $ECHO "N/A, Not available."
    fi
}

function main()
{
    showHeadline

    $ECHO "---------------------------------------------------------------------------"
    $ECHO ">>> Current time: "
    showCurrentTime

    $ECHO "---------------------------------------------------------------------------"
    $ECHO ">>> System info: "
    showSystemInfo

    $ECHO "---------------------------------------------------------------------------"
    $ECHO ">>> Linux distribution info: "
    showLinuxDistribution

    $ECHO "---------------------------------------------------------------------------"
    $ECHO ">>> BIOS/DMI info: "
    showBIOSDMI

    $ECHO "---------------------------------------------------------------------------"
    $ECHO ">>> PCI info: "
    showPCIInfo

    $ECHO "---------------------------------------------------------------------------"
    $ECHO ">>> Loaded modules Info before running SuperoDoctor: "
    showLoadedModule

    $ECHO "---------------------------------------------------------------------------"
    $ECHO ">>> SuperoDoctor info: "
    showSDInfo

    $ECHO "---------------------------------------------------------------------------"
    $ECHO ">>> Loaded modules Info after running SuperoDoctor: "
    showLoadedModule

    $ECHO "---------------------------------------------------------------------------"
    $ECHO ">>> I2C bus info: "
    showI2CBus
}


showHeadline
main > $OUTPUT_TXT
if [ -f $OUTPUTT_TXT ]; then
    $ECHO ">>> Supero Doctor Report: $OUTPUT_TXT"
    $LS -l $OUTPUT_TXT
    $ECHO
else
    $ECHO ">>> Error: Cannot create Supero Doctor Report!"
    $ECHO
fi

